/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun type 2 keyboard.
 */

static const KeyCode sun2_codes [] = {

  /* Row 0 */
  8, 10,
  12, 13, 15, 17, 19, 21, 23, 24, 25, 26,
  28, 29, 30,
  
  /* Row 1 */
  32, 33,
  36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
  52, 53, 54,
  
  /* Row 2 */
  56, 58,
  60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73,
  75, 76, 77,
  
  /* Row 3 */
  79, 80,
  83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96,
  98, 99, 100,
  
  /* Row 4 */
  102, 104,
  106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118,
  119, 120, 121,
  
  /* Row 5 */
  127, 128, 129
};
